@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,8 +20,7 @@
 
 #include <QListView>
 #include "pimcommonakonadi_private_export.h"
-namespace PimCommon
-{
+namespace PimCommon {
 class PIMCOMMONAKONADI_TESTS_EXPORT AclListView : public QListView
 {
     Q_OBJECT
